Crate opus_embedded_sys

Crate opus_embedded_sys 

Minimal bindings for opus decoder.

Focused on no_alloc use on embedded ARM platforms.

The documentation is not very well-formatted in places and you might want to look at Opus documentation instead instead. In particular, the page about Opus Decoder may be handy.

Structs

OpusDecoder
Struct big enough to contain OpusDecoder of opus-1.5.2 so it can be reserved on stack.

Constants

OPUS_ALLOC_FAIL
OPUS_BAD_ARG
OPUS_BANDWIDTH_FULLBAND
OPUS_BANDWIDTH_MEDIUMBAND
OPUS_BANDWIDTH_NARROWBAND
OPUS_BANDWIDTH_SUPERWIDEBAND
OPUS_BANDWIDTH_WIDEBAND
OPUS_BUFFER_TOO_SMALL
OPUS_DECODER_SIZE_CH1
OPUS_DECODER_SIZE_CH2
OPUS_INTERNAL_ERROR
OPUS_INVALID_PACKET
OPUS_INVALID_STATE
OPUS_OK
OPUS_UNIMPLEMENTED

Functions

opus_decode
Decode an Opus packet.
opus_decoder_create
Allocates and initializes a decoder state.
opus_decoder_destroy
Frees an OpusDecoder allocated by opus_decoder_create().
opus_decoder_get_nb_samples
Gets the number of samples of an Opus packet.
opus_decoder_get_size
Gets the size of an OpusDecoder structure.
opus_decoder_init
Initializes a previously allocated decoder state. The state must be at least the size returned by opus_decoder_get_size(). This is intended for applications which use their own allocator instead of malloc. See also opus_decoder_create and opus_decoder_get_size. To reset a previously initialized state, use the OPUS_RESET_STATE CTL.
opus_packet_get_bandwidth
Gets the bandwidth of an Opus packet.
opus_packet_get_nb_channels
Gets the number of channels from an Opus packet.
opus_packet_get_nb_frames
Gets the number of frames in an Opus packet.
opus_packet_get_nb_samples
Gets the number of samples of an Opus packet.
opus_packet_get_samples_per_frame
Gets the number of samples per frame from an Opus packet.
opus_strerror
Converts an opus error code into a human readable string.

Type Aliases

opus_int16
opus_int32