opus_packet_get_samples_per_frame

Function opus_packet_get_samples_per_frame 

pub unsafe extern "C" fn opus_packet_get_samples_per_frame(
    data: *const c_uchar,
    Fs: opus_int32,
) -> c_int
Gets the number of samples per frame from an Opus packet.

Arguments

  • data [in] - char*: Opus packet. This must contain at least one byte of data.
  • Fs [in] - opus_int32: Sampling rate in Hz. This must be a multiple of 400, or inaccurate results will be returned.

Returns

Number of samples per frame.