Minimal bindings for opus decoder.
Focused on no_alloc use on embedded ARM platforms.
The documentation is not very well-formatted in places and you might want to look at Opus documentation instead instead. In particular, the page about Opus Decoder may be handy.
Structs
- Opus
Decoder - Struct big enough to contain OpusDecoder of opus-1.5.2 so it can be reserved on stack.
Constants
- OPUS_
ALLOC_ FAIL - OPUS_
BAD_ ARG - OPUS_
BANDWIDTH_ FULLBAND - OPUS_
BANDWIDTH_ MEDIUMBAND - OPUS_
BANDWIDTH_ NARROWBAND - OPUS_
BANDWIDTH_ SUPERWIDEBAND - OPUS_
BANDWIDTH_ WIDEBAND - OPUS_
BUFFER_ TOO_ SMALL - OPUS_
DECODER_ SIZE_ CH1 - OPUS_
DECODER_ SIZE_ CH2 - OPUS_
INTERNAL_ ERROR - OPUS_
INVALID_ PACKET - OPUS_
INVALID_ STATE - OPUS_OK
- OPUS_
UNIMPLEMENTED
Functions
- opus_
decode ⚠ - Decode an Opus packet.
- opus_
decoder_ ⚠create - Allocates and initializes a decoder state.
- opus_
decoder_ ⚠destroy - Frees an
OpusDecoderallocated by opus_decoder_create(). - opus_
decoder_ ⚠get_ nb_ samples - Gets the number of samples of an Opus packet.
- opus_
decoder_ ⚠get_ size - Gets the size of an
OpusDecoderstructure. - opus_
decoder_ ⚠init - Initializes a previously allocated decoder state.
The state must be at least the size returned by opus_decoder_get_size().
This is intended for applications which use their own allocator instead of malloc.
See also
opus_decoder_createandopus_decoder_get_size. To reset a previously initialized state, use theOPUS_RESET_STATECTL. - opus_
packet_ ⚠get_ bandwidth - Gets the bandwidth of an Opus packet.
- opus_
packet_ ⚠get_ nb_ channels - Gets the number of channels from an Opus packet.
- opus_
packet_ ⚠get_ nb_ frames - Gets the number of frames in an Opus packet.
- opus_
packet_ ⚠get_ nb_ samples - Gets the number of samples of an Opus packet.
- opus_
packet_ ⚠get_ samples_ per_ frame - Gets the number of samples per frame from an Opus packet.
- opus_
strerror ⚠ - Converts an opus error code into a human readable string.