pub unsafe extern "C" fn opus_decoder_init(
st: *mut OpusDecoder,
Fs: opus_int32,
channels: c_int,
) -> c_intExpand description
Initializes a previously allocated decoder state.
The state must be at least the size returned by opus_decoder_get_size().
This is intended for applications which use their own allocator instead of malloc.
See also opus_decoder_create and opus_decoder_get_size.
To reset a previously initialized state, use the OPUS_RESET_STATE CTL.
Arguments
st[in] - OpusDecoder*: Decoder state.Fs[in] - opus_int32: Sampling rate to decode to (Hz). This must be one of 8000, 12000, 16000, 24000, or 48000.channels[in] - int: Number of channels (1 or 2) to decode
Returns
OPUS_OKSuccess or opus error codes